from setuphelpers import *
import platform

uninstallkey = []

# Declaring specific app values (TO CHANGE)
bin_name_string = 'vlc-%s-win64.exe'
silent_inst_arg = '/S'
uninstall_key = 'VLC media player'


def install():
    # Specific app values
    package_version = control.version.split('-',1)[0]

    # Installing the package
    install_exe_if_needed(bin_name_string % package_version
        ,silentflags=silent_inst_arg
        ,key=uninstall_key
        ,min_version=package_version)

    remove_desktop_shortcut('VLC media player')


def session_setup():
    print("Setting up default preferences for VLC")

    # Specific app values
    user_conf_dir = makepath(user_appdata,'vlc')
    user_conf_file = makepath(user_appdata,'vlc','vlcrc')
    vlcrc_content="""[qt] # Qt interface
qt-notification=0
qt-updates-notif=0
qt-privacy-ask=0
metadata-network-access=0
"""

    if not isfile(user_conf_file):
        if not isdir(user_conf_dir):
            mkdirs(user_conf_dir)
        fichier = open(user_conf_file, "w")
        fichier.write(vlcrc_content)
        fichier.close()
    else:
        fichier = open(user_conf_file,"r")
        data = fichier.read()
        fichier.close()

        if '#qt-notification=1' in data :
            data = data.replace('#qt-notification=1','qt-notification=0')
        if 'qt-notification=1' in data :
            data = data.replace('qt-notification=1','qt-notification=0')
        if '#qt-updates-notif=1' in data :
            data = data.replace('#qt-updates-notif=1','qt-updates-notif=0')
        if 'qt-updates-notif=1' in data :
            data = data.replace('qt-updates-notif=1','qt-updates-notif=0')
        if '#qt-privacy-ask=1' in data :
            data = data.replace('#qt-privacy-ask=1','qt-privacy-ask=0')
        if 'qt-privacy-ask=1' in data :
            data = data.replace('qt-privacy-ask=1','qt-privacy-ask=0')
        if '#metadata-network-access=1' in data :
            data = data.replace('#metadata-network-access=1','metadata-network-access=0')
        if 'metadata-network-access=1' in data :
            data = data.replace('metadata-network-access=1','metadata-network-access=0')
            
        fichier = open(user_conf_file, "w")
        fichier.write(data)
        fichier.close()


def update_package():
    print('Update package content from upstream binary sources')

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system()=='Windows' and isfile(makepath(user_local_appdata(),'waptconsole','waptconsole.ini')):
        proxywapt = inifile_readstring(makepath(user_local_appdata(),'waptconsole','waptconsole.ini'),'global','http_proxy')
        if proxywapt :
            proxy = {'http':proxywapt,'https':proxywapt}

    htmlSource = wgets("http://www.videolan.org/vlc/download-windows.html",proxies=proxy).splitlines()

    for line in htmlSource :
        if 'downloadOS' in line :
            realversion = line[line.find("") + 12 :line.find("</span>")]
            latest_bin = bin_name_string % realversion

    # Deleting outdated binaries
    for actual_bin in glob.glob('*.exe') or glob.glob('*.msi'):
        if actual_bin != latest_bin :
            print(actual_bin + ' Deleted')
            remove_file(actual_bin)

    # Downloading latest binaires
    if not isfile(latest_bin):
        print('Download ' + latest_bin)
        win_arch = control.architecture.replace('x','win')
        if win_arch == 'win86':
            win_arch = 'win32'
        wget('https://get.videolan.org/vlc/'+ realversion +'/%s/' % win_arch + latest_bin, latest_bin,proxies=proxy)

        pe = PackageEntry().load_control_from_wapt('.')
        pe.version = '%s-%s'%(realversion,int(pe.version.split('-',1)[1])+1)
        pe.save_control_to_wapt('.')
        print('Changing version to ' + pe.version + ' in WAPT\\control')

